<?php
/**
 * Storefront engine room
 *
 * @package storefront
 */

/**
 * Assign the Storefront version to a var
 */
$theme              = wp_get_theme( 'storefront' );
$storefront_version = $theme['Version'];

/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) ) {
	$content_width = 980; /* pixels */
}

$storefront = (object) array(
	'version'    => $storefront_version,

	/**
	 * Initialize all the things.
	 */
	'main'       => require 'inc/class-storefront.php',
	'customizer' => require 'inc/customizer/class-storefront-customizer.php',
);

require 'inc/storefront-functions.php';
require 'inc/storefront-template-hooks.php';
require 'inc/storefront-template-functions.php';
require 'inc/wordpress-shims.php';

if ( class_exists( 'Jetpack' ) ) {
	$storefront->jetpack = require 'inc/jetpack/class-storefront-jetpack.php';
}

if ( storefront_is_woocommerce_activated() ) {
	$storefront->woocommerce            = require 'inc/woocommerce/class-storefront-woocommerce.php';
	$storefront->woocommerce_customizer = require 'inc/woocommerce/class-storefront-woocommerce-customizer.php';

	require 'inc/woocommerce/class-storefront-woocommerce-adjacent-products.php';

	require 'inc/woocommerce/storefront-woocommerce-template-hooks.php';
	require 'inc/woocommerce/storefront-woocommerce-template-functions.php';
	require 'inc/woocommerce/storefront-woocommerce-functions.php';
}

if ( is_admin() ) {
	$storefront->admin = require 'inc/admin/class-storefront-admin.php';

	require 'inc/admin/class-storefront-plugin-install.php';
}

/**
 * NUX
 * Only load if wp version is 4.7.3 or above because of this issue;
 * https://core.trac.wordpress.org/ticket/39610?cversion=1&cnum_hist=2
 */
if ( version_compare( get_bloginfo( 'version' ), '4.7.3', '>=' ) && ( is_admin() || is_customize_preview() ) ) {
	require 'inc/nux/class-storefront-nux-admin.php';
	require 'inc/nux/class-storefront-nux-guided-tour.php';

	if ( defined( 'WC_VERSION' ) && version_compare( WC_VERSION, '3.0.0', '>=' ) ) {
		require 'inc/nux/class-storefront-nux-starter-content.php';
	}
}

/**
 * Note: Do not add any custom code here. Please use a custom plugin so that your customizations aren't lost during updates.
 * https://github.com/woocommerce/theme-customisations
 */
 
 
 
include('inc/shortcodes.php');
include('functions/catalog.php');


// Scripts
add_action( 'wp_enqueue_scripts', 'theme_name_scripts' );
// add_action('wp_print_styles', 'theme_name_scripts'); // можно использовать этот хук он более поздний
function theme_name_scripts() {
	
	wp_enqueue_style( 'normalize.css', get_template_directory_uri().'/module/normalize/normalize.css' );
	wp_enqueue_style( 'owl.carousel.min.css',get_template_directory_uri().'/module/owl-carousel/owl.carousel.min.css' );
	wp_enqueue_style( 'jquery.fancybox.min.css', get_template_directory_uri().'/module/fancybox/jquery.fancybox.min.css' );
	wp_enqueue_style( 'jquery.formstyler.css', get_template_directory_uri().'/module/formstyler/jquery.formstyler.css' );
	wp_enqueue_style( 'jquery.formstyler.theme.css', get_template_directory_uri().'/module/formstyler/jquery.formstyler.theme.css' );
	wp_enqueue_style( 'style.css', get_template_directory_uri().'/css/style.css' );
	
	/*wp_enqueue_script( 'jquery.min.js', get_template_directory_uri() . '/module/jquery/jquery.min.js' );
	wp_enqueue_script( 'jquery.fancybox.min.js', get_template_directory_uri() . '/module/fancybox/jquery.fancybox.min.js' );
	wp_enqueue_script( 'jquery.sticky.js', get_template_directory_uri() . '/module/sticky/jquery.sticky.js' );
	wp_enqueue_script( 'jquery.formstyler.min.js', get_template_directory_uri() . '/module/formstyler/jquery.formstyler.min.js' );
	wp_enqueue_script( 'owl.carousel.min.js', get_template_directory_uri() . '/module/owl-carousel/owl.carousel.min.js' );
	wp_enqueue_script( 'jquery.inputmask.min.js', get_template_directory_uri() . '/module/maskinput/jquery.inputmask.min.js' );
	wp_enqueue_script( 'jquery.matchHeight-min.js', get_template_directory_uri() . '/module/match-height/jquery.matchHeight-min.js' );
	wp_enqueue_script( 'bundle.min.js', get_template_directory_uri() . '/js/bundle.min.js' );*/
	
}


add_theme_support( 'menus' );
add_action( 'init', 'register_my_menus' );

function register_my_menus() {
	register_nav_menus(
		array(
			//'primary-menu' => __( 'Primary Menu' ),
			//'secondary-menu' => __( 'Secondary Menu' )
			'bottom-1' => __( 'Bottom 1' ),
			'bottom-2' => __( 'Bottom 2' ),
			'bottom-3' => __( 'Bottom 3' ),
		)
	);
} 


add_action('init', 'save_review_form');
function save_review_form() {
	
	if( $_POST['action'] == 'save_review' ) {
		
		if( $_POST['review'] != '' ) {
			
			$title = "Review #".rand(0, 100000);
			
			$post_data = array(
				'post_title'    => wp_strip_all_tags( $title ),
				'post_content'  => $_POST['review'],
				'post_status'   => 'draft',
				'post_type'   => 'product_reviews',
				'post_author'   => 1,
			);

			// Вставляем запись в базу данных
			$post_id = wp_insert_post( $post_data );
			
			update_post_meta( $post_id, 'product_id', $_POST['product_id'] );
			update_post_meta( $post_id, 'user_id', get_current_user_id() );
			update_post_meta( $post_id, 'rating', $_POST['rating'] );
			
		}
	
		echo "<pre>";
		print_r( $_POST );
		echo "</pre>";
		
		exit();
	
	}
	
}

/* 
function get_breadcrumb() {
echo ”;
echo ‘Home‘;
if (is_category()) {
echo ”  »  “;
$category = get_queried_object();
$currentId = $category->term_id;
$currentNm = $category->name;

$categories = get_categories(array(‘parent’=>0));
foreach ( $categories as $category ) {
$cat = get_categories(array(‘parent’=>$category->term_id));
$parentId = $category->term_id;
$parentNm = $category->name;
if ($category->term_id == $currentId) {
?><a href=" “>term_id == $currentId) {
?><a href=" “><a href=" “><?php
}
}
}
}
} elseif (is_single()) {
echo "  »  ";
the_category(' • ');
echo "  »  ";
the_title();

} elseif (is_page()) {
echo "  »  ";
echo the_title();
} elseif (is_search()) {
echo "  »  Search Results for… ";
echo '"‘;
echo the_search_query();
echo ‘“‘;
}
echo ”;
}
*/ 
 
 
 
 
 
 
 
